@@ -6,6 +6,10 @@ with contextlib.suppress(ImportError):
     from .io_aiohttp import AioHTTPTelegramApi
     __all__ += io_aiohttp.__all__
 
+with contextlib.suppress(ImportError):
+    from .io_httpx import HTTPxTelegramApi
+    __all__ += io_httpx.__all__
+
 with contextlib.suppress(ImportError):
     from .io_requests import RequestsTelegramApi
     __all__ += io_requests.__all__
